# -*- coding: utf-8 -*-
"""Methods for plotting precipitation and motion fields."""

from .motionfields import *
from .precipfields import *
from .animations import *
from .spectral import *
from .thunderstorms import *
